summaryrefslogtreecommitdiff
path: root/nuttx/include/nuttx/usb/usbhost.h
diff options
context:
space:
mode:
authorpatacongo <patacongo@42af7a65-404d-4744-a932-0658087f49c3>2010-12-21 11:21:07 +0000
committerpatacongo <patacongo@42af7a65-404d-4744-a932-0658087f49c3>2010-12-21 11:21:07 +0000
commite276f17ab5f7c64e50bbf4bf88fd17d8718096e3 (patch)
tree242d5b925d5becf4e3f2810f168723f5b7f17cdd /nuttx/include/nuttx/usb/usbhost.h
parent923217b39059d97f275771a13d032da287b7327f (diff)
downloadnuttx-e276f17ab5f7c64e50bbf4bf88fd17d8718096e3.tar.gz
nuttx-e276f17ab5f7c64e50bbf4bf88fd17d8718096e3.tar.bz2
nuttx-e276f17ab5f7c64e50bbf4bf88fd17d8718096e3.zip
Clean up comments
git-svn-id: svn://svn.code.sf.net/p/nuttx/code/trunk@3207 42af7a65-404d-4744-a932-0658087f49c3
Diffstat (limited to 'nuttx/include/nuttx/usb/usbhost.h')
-rw-r--r--nuttx/include/nuttx/usb/usbhost.h16
1 files changed, 9 insertions, 7 deletions
diff --git a/nuttx/include/nuttx/usb/usbhost.h b/nuttx/include/nuttx/usb/usbhost.h
index 2139df5e2..8a7457bbd 100644
--- a/nuttx/include/nuttx/usb/usbhost.h
+++ b/nuttx/include/nuttx/usb/usbhost.h
@@ -94,10 +94,10 @@
#define CLASS_CREATE(reg, drvr, id) ((reg)->create(drvr, id))
/************************************************************************************
- * Name: CLASS_CONFIGDESC
+ * Name: CLASS_CONNECT
*
* Description:
* This macro will call the configdesc() method of struct usbhost_class_s. This
* method is a callback into the class implementation. It is used to provide the
* device's configuration descriptor to the class so that the class may initialize
* properly
@@ -112,11 +112,13 @@
* returned indicating the nature of the failure
*
* Assumptions:
- * This function may be called from an interrupt handler.
+ * This function is probably called on the same thread that called the driver
+ * enumerate() method. However, this function may also be called from an
+ * interrupt handler.
*
************************************************************************************/
-#define CLASS_CONFIGDESC(class,configdesc,desclen) ((class)->configdesc(class,configdesc,desclen))
+#define CLASS_CONNECT(class,configdesc,desclen) ((class)->connect(class,configdesc,desclen))
/************************************************************************************
* Name: CLASS_DISCONNECTED
@@ -174,7 +176,7 @@
* extract the class ID info from the configuration descriptor, (3) call
* usbhost_findclass() to find the class that supports this device, (4)
* call the create() method on the struct usbhost_registry_s interface
* to get a class instance, and finally (5) call the configdesc() method
* of the struct usbhost_class_s interface. After that, the class is in
* charge of the sequence of operations.
*
@@ -399,7 +401,7 @@ struct usbhost_class_s
* initialize properly (such as endpoint selections).
*/
- int (*configdesc)(FAR struct usbhost_class_s *class, FAR const uint8_t *configdesc, int desclen);
+ int (*connect)(FAR struct usbhost_class_s *class, FAR const uint8_t *configdesc, int desclen);
/* This method informs the class that the USB device has been disconnected. */
@@ -422,7 +424,7 @@ struct usbhost_driver_s
* extract the class ID info from the configuration descriptor, (3) call
* usbhost_findclass() to find the class that supports this device, (4)
* call the create() method on the struct usbhost_registry_s interface
* to get a class instance, and finally (5) call the configdesc() method
* of the struct usbhost_class_s interface. After that, the class is in
* charge of the sequence of operations.
*/
@@ -94,10 +94,10 @@
*
* Description:
- * This macro will call the configdesc() method of struct usbhost_class_s. This
+ * This macro will call the connect() method of struct usbhost_class_s. This
* method is a callback into the class implementation. It is used to provide the
* device's configuration descriptor to the class so that the class may initialize
@@ -174,7 +176,7 @@
* usbhost_findclass() to find the class that supports this device, (4)
* call the create() method on the struct usbhost_registry_s interface
- * to get a class instance, and finally (5) call the configdesc() method
+ * to get a class instance, and finally (5) call the connect() method
* of the struct usbhost_class_s interface. After that, the class is in
* charge of the sequence of operations.
@@ -422,7 +424,7 @@ struct usbhost_driver_s
* usbhost_findclass() to find the class that supports this device, (4)
* call the create() method on the struct usbhost_registry_s interface
- * to get a class instance, and finally (5) call the configdesc() method
+ * to get a class instance, and finally (5) call the connect() method
* of the struct usbhost_class_s interface. After that, the class is in
* charge of the sequence of operations.